<?php
/*
 * Version: 1.0.3
 */



if (!class_exists('oftnPremium')) {

	class oftnPremium {

		public static function plugin_version() {

            return options_for_twenty_nineteen_premium_class::$version;

        }

		public static function plugin_common_class() {

            return str_replace('Premium', 'Common', get_called_class());

		}

		public static function check_plugin_update($transient) {

            $plugin_to_check = array(
                'slug' => call_user_func(self::plugin_common_class() .'::plugin_text_domain') . '-premium',
                'plugin' => call_user_func(self::plugin_common_class() .'::plugin_text_domain') . '-premium/' . call_user_func(self::plugin_common_class() .'::plugin_text_domain') . '-premium.php',
                'version' =>  self::plugin_version()
            );

            if (!isset($transient->response[$plugin_to_check['plugin']]->new_version)) {

                $url = add_query_arg(
                    array(
                        'action' => 'plugin_version',
                        'plugin' => $plugin_to_check['slug']
                    ),
                    'https://webd.uk/wp-admin/admin-ajax.php'
                );
                $response = wp_remote_request($url);

                if(!is_wp_error($response) && isset($response['response']['code']) && $response['response']['code'] == 200 && isset($response['body'])) {

                    $plugin_version = json_decode($response['body']);

                    if (is_object($plugin_version) && isset($plugin_version->new_version) && isset($plugin_version->tested) && isset($plugin_version->changelog) && version_compare(preg_replace("/[^0-9.]/", '', $plugin_version->new_version), $plugin_to_check['version'], '>')) {

                        $plugin_update = new stdClass();
                        $plugin_update->id = 'webd.uk/' . call_user_func(self::plugin_common_class() .'::plugin_text_domain') . '/';
                        $plugin_update->slug = $plugin_to_check['slug'];
                        $plugin_update->plugin = $plugin_to_check['plugin'];
                        $plugin_update->new_version = preg_replace("/[^0-9.]/", '', $plugin_version->new_version);
                        $plugin_update->url = 'https://' . $plugin_update->id;
                        $plugin_update->package = 'https://webd.uk/downloads/' . call_user_func(self::plugin_common_class() .'::plugin_text_domain') . '-premium.' . $plugin_update->new_version . '.zip';
                        $plugin_update->icons = array(
                            '2x' => 'https://ps.w.org/' . call_user_func(self::plugin_common_class() .'::plugin_text_domain') . '/assets/icon-256x256.jpg',
                            '1x' => 'https://ps.w.org/' . call_user_func(self::plugin_common_class() .'::plugin_text_domain') . '/assets/icon-128x128.jpg'
                        );
                        $plugin_update->tested = preg_replace("/[^0-9.]/", '', $plugin_version->tested);
                        $plugin_update->upgrade_notice = sanitize_text_field($plugin_version->changelog);
                        $transient->response[$plugin_to_check['plugin']] = $plugin_update;  

                    }

                }

            }

            return $transient;
        }

		public static function get_plugin_information($result, $action, $args) {

            $plugin_slug = call_user_func(self::plugin_common_class() .'::plugin_text_domain') . '-premium';

            if ($action == 'plugin_information' && isset($args->slug) && $args->slug == $plugin_slug) {

                $url = add_query_arg(
                    array(
                        'action' => 'plugin_information',
                        'plugin' => $plugin_slug
                    ),
                    'https://webd.uk/wp-admin/admin-ajax.php'
                );
                $response = wp_remote_request($url);

                if(!is_wp_error($response) && isset($response['response']['code']) && $response['response']['code'] == 200 && isset($response['body'])) {

                    $plugin_information = json_decode($response['body']);

                    if (is_object($plugin_information) && isset($plugin_information->version) && isset($plugin_information->tested) && isset($plugin_information->requires) && isset($plugin_information->sections->changelog)) {

                        $clean_information = new stdClass();
                        $clean_information->last_updated = sanitize_text_field($plugin_information->last_updated);
                        $clean_information->slug = $plugin_slug;
                        $clean_information->version = preg_replace("/[^0-9.]/", '', $plugin_information->version);
                        $clean_information->author = '<a href=\"https://webd.uk\">webd.uk</a>';
                        $clean_information->homepage = 'https://webd.uk/' . call_user_func(self::plugin_common_class() .'::plugin_text_domain') . '/';
                        $clean_information->download_link = 'https://webd.uk/downloads/' . call_user_func(self::plugin_common_class() .'::plugin_text_domain') . '-premium.' . $clean_information->version . '.zip';
                        $clean_information->tested = preg_replace("/[^0-9.]/", '', $plugin_information->tested);
                        $clean_information->requires = preg_replace("/[^0-9.]/", '', $plugin_information->requires);
                        $clean_information->name = call_user_func(self::plugin_common_class() .'::plugin_name') . ' Premium';
                        $clean_information->sections = array(
                            'changelog' => wp_kses($plugin_information->sections->changelog, array( 
                                'h4' => array(),
                                'ul' => array(),
                                'li' => array()
                            ))
                        );

                        return $clean_information;

                    }

                }

            }

            return false;
        }

		public static function start_trial() {

        	if (!get_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_trial_date') && !get_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_purchased')) {

                update_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_trial_date', time());
                add_action('admin_notices', array(get_called_class(), 'trial_started_notice'));

        	}

        }

		public static function trial_started_notice() {

?>
<div class="notice notice-info">
<p><strong><?= __(call_user_func(self::plugin_common_class() .'::plugin_name') . ' Trial Started', call_user_func(self::plugin_common_class() .'::plugin_text_domain')); ?></strong><br />
<?= __('Your free 7 day trial of ' . call_user_func(self::plugin_common_class() .'::plugin_name') . ' has started.', call_user_func(self::plugin_common_class() .'::plugin_text_domain')); ?></p>
</div>
<?php

        }

		public static function activate_upgrade() {

        	if (check_admin_referer(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_activate') && current_user_can('manage_options')) {

                $http_url = 'https://webd.uk/activate/';
                $http_args = array(
                    'timeout' => 15,
                    'body' => array(
                        'url' => ((isset($_SERVER['HTTPS']) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST']),
                        'plugin' => call_user_func(self::plugin_common_class() .'::plugin_text_domain')
                    )
                );
                $request = wp_remote_post($http_url, $http_args);

                if (is_wp_error($request)) {

					delete_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_purchased');
                    add_action('admin_notices', array(get_called_class(), 'activation_cannot_connect_notice'));

                } elseif (isset($request['body']) && $request['body'] == 'True') {

					update_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_purchased', true);
                    add_action('admin_notices', array(get_called_class(), 'activation_success_notice'));

				} else {

					delete_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_purchased');
                    add_action('admin_notices', array(get_called_class(), 'activation_failed_notice'));

				}

        	}

        }

		public static function activation_cannot_connect_notice() {

?>
<div class="notice notice-error">
<p><strong><?= __(call_user_func(self::plugin_common_class() .'::plugin_name') . ' Premium Activation Error', call_user_func(self::plugin_common_class() .'::plugin_text_domain')); ?></strong><br />
<?= __('The purchase activation has failed because your website cannot connect to webd.uk to confirm your purchase. Please contact your Service provider to ask them to unblock webd.uk and if they cannot help you please contact us so we can investigate further.', call_user_func(self::plugin_common_class() .'::plugin_text_domain')); ?></p>
</div>
<?php

        }

		public static function activation_failed_notice() {

?>

<div class="notice notice-error">
<p><strong><?= __(call_user_func(self::plugin_common_class() .'::plugin_name') . ' Premium Activation Error', call_user_func(self::plugin_common_class() .'::plugin_text_domain')); ?></strong><br />
<?= sprintf(wp_kses(__('Please <a href="%s">purchase an upgrade</a> first. If you have already purchased an upgrade for this plugin, please contact us so we can investigate the issue.', call_user_func(self::plugin_common_class() .'::plugin_text_domain')), array('a' => array('href' => array()))), esc_url(call_user_func(self::plugin_common_class() .'::upgrade_link'))); ?></p>
</div>

<?php

        }

		public static function activation_success_notice() {

?>
<div class="notice notice-info">
<p><strong><?= __(call_user_func(self::plugin_common_class() .'::plugin_name') . ' Premium Activation Successful', call_user_func(self::plugin_common_class() .'::plugin_text_domain')); ?></strong><br />
<?= __('Thank you for purchasing ' . call_user_func(self::plugin_common_class() .'::plugin_name') . ' Premium. The plugin purchase has been activated successfully.', call_user_func(self::plugin_common_class() .'::plugin_text_domain')); ?></p>
</div>
<?php

        }

		public static function schedule_check() {

            if (get_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_purchased') && (get_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_check') != md5($_SERVER['HTTP_HOST'] . call_user_func(self::plugin_common_class() .'::plugin_version')))) {

    			delete_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_check');
                $client_host = $_SERVER['HTTP_HOST'];
                $client_host = preg_replace('#^www.#', '', $client_host);
                $client_host = preg_replace('#^test.#', '', $client_host);
                $client_host = preg_replace('#^dev.#', '', $client_host);

                if (strpos($client_host, ':')) {

                    $client_host = substr($client_host, 0, strpos($client_host, ':'));

                }

                if (filter_var($client_host, FILTER_VALIDATE_IP) || $client_host == 'localhost') {

                    update_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_check', md5($_SERVER['HTTP_HOST'] . call_user_func(self::plugin_common_class() .'::plugin_version')));

                }

                if (!get_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_check')) {
   
                    if (!wp_next_scheduled(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_check')) {

                        wp_schedule_event(time()+3600, 'daily', call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_check');

                    } 
    
                }

            }

		}

		public static function scheduled_check() {

            if (isset($_SERVER['HTTP_HOST']) && $_SERVER['HTTP_HOST']) {

                $http_url = 'https://webd.uk/activate/';
                $http_args = array(
                    'timeout' => 15,
                    'body' => array(
                        'url' => ((isset($_SERVER['HTTPS']) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST']),
                        'plugin' => call_user_func(self::plugin_common_class() .'::plugin_text_domain'),
                        'check' => true
                    )
                );
                $request = wp_remote_post($http_url, $http_args);

                if (!is_wp_error($request) && isset($request['body']) && $request['body'] == 'True') {

                    update_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_check', md5($_SERVER['HTTP_HOST'] . call_user_func(self::plugin_common_class() .'::plugin_version')));
                    wp_clear_scheduled_hook(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_check');

    			} elseif (!is_wp_error($request) && isset($request['body']) && $request['body'] == 'False') {

    				delete_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_purchased');
                    update_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_trial_date', time()-604800);
                    wp_clear_scheduled_hook(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_check');

    			}

            }

        }

		public static function request_permission($front_end = false) {

            $bd = array(
                'b5b2582c9b15de9fb1ea461ba04566df',
                '8eb9de4da959af9e2824d82e709cabdb',
                '8754368c70b789c16f13f41c9039664f',
                '77d451d5cab197f97c1689d81291aefb',
                'e991e11370d904a93ed4d29c716574ec',
                'ffb1918eace707285429a2b5e1265945',
                'fc034647d53e106bc1c365d731c04c02',
                '2aec02b389034af017db3abdceca1d28',
                'b9adca005e8a4fcfb5fdf456864b3316',
                'e7854343aac96885d2e84fa1ee3e9b0c',
                'dbada7d7ae47af3f1f809fc93c557e06',
                '29e110922e3ce3a423f69ef79be8e8f9',
                'b4f05b6a5ea56ac7f793c6533a10205c',
                '50044561a91276fd135facc1870cbade',
                'a57efea9a91ad50aebcafd759ca8d6ea',
                'f517f5fa5502d4eb5ff3ecd6336f92b1',
                'ee53588f778ce8d7a427bc6bd0f4ac11',
                '4438f3ec1a6b75950fba6440bf711dad',
                '32a49088d454409a95ddbedb161a9628',
                '3085724c1b30e19c5807e129e9811e91',
                '4e67f85eab9e901900bea8509edbdec8',
                '693c9fbc41dfbee4519286f463eb4011',
                '061317215c2ea0303f2d672233d77be3',
                'fa51e5e1c1d0097322c494a7f24dce00'
            );

            if (isset($_SERVER['HTTP_HOST']) && in_array(md5($_SERVER['HTTP_HOST']), $bd)) {

                return false;

            }

            if ((get_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_trial_date') && time() < (strtotime('+1 week', get_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_trial_date')))) || get_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_purchased')) {

                return true;

            } elseif (!$front_end) {

                $current_user = wp_get_current_user();

                $gd = array(
					'e37ed9994bc1790ed0e0ca45906d8401',
					'4b3c2ad1c75cbf2f6c17fa6c6abc7d78',
					'700c909af8c216b8df4a83db0c154219'
                );

                if (in_array(md5(substr(strrchr($current_user->user_email, "@"), 1)), $gd)) {

                    return true;

                } else {

                    return false;

                }

            } else {

                if (get_option(call_user_func(self::plugin_common_class() .'::plugin_prefix') . '_trial_date')) {

                    return false;

                } else {

                    return true;

                }

            }

        }

	}

}

?>
